pub enum SourceManagerError {
InvalidSourceId,
InvalidBounds,
InvalidContentUpdate(SourceContentUpdateError),
Custom {
error_msg: Box<str>,
source: Option<Box<dyn Error + Send + Sync + 'static>>,
},
}Expand description
The set of errors which may be raised by a SourceManager
Variants
InvalidSourceId
A SourceId was provided to a SourceManager which was allocated by a different SourceManager
InvalidBounds
An attempt was made to read content using invalid byte indices
InvalidContentUpdate(SourceContentUpdateError)
Custom
Custom error variant for implementors of the trait.
Implementations