pub struct FileLineCol {
pub uri: FileName,
pub line: LineNumber,
pub column: ColumnNumber,
}Expand description
A FileLineCol represents traditional file/line/column information for use in rendering.
Fields
uri: FileNameThe path to the source file in which the relevant source code can be found
line: LineNumberThe one-indexed number of the line to which this location refers
column: ColumnNumberThe one-indexed column of the line on which this location starts
Implementations
Sourceimpl FileLineCol
impl FileLineCol
Sourcepub fn new(
uri: FileName,
line: impl Into<LineNumber>,
column: impl Into<ColumnNumber>,
) -> Self
pub fn new( uri: FileName, line: impl Into<LineNumber>, column: impl Into<ColumnNumber>, ) -> Self
Creates a new Location.
Sourcepub const fn line(&self) -> LineNumber
pub const fn line(&self) -> LineNumber
Returns the line of the location.
Sourcepub fn move_column(&mut self, offset: i32)
pub fn move_column(&mut self, offset: i32)
Moves the column by the given offset.