LabeledSpan

Struct LabeledSpan 

pub struct LabeledSpan { /* private fields */ }
A labeled SourceSpan.

Implementations

Source

impl LabeledSpan

pub const fn new( label: Option<String>, offset: usize, len: usize, ) -> LabeledSpan

Makes a new labeled span.

pub fn new_with_span( label: Option<String>, span: impl Into<SourceSpan>, ) -> LabeledSpan

Makes a new labeled span using an existing span.

pub fn new_primary_with_span( label: Option<String>, span: impl Into<SourceSpan>, ) -> LabeledSpan

Makes a new labeled primary span using an existing span.

pub fn set_label(&mut self, label: Option<String>)

Change the text of the label

pub fn at(span: impl Into<SourceSpan>, label: impl Into<String>) -> LabeledSpan

Makes a new label at specified span

Examples
use miette::LabeledSpan;

let source = "Cpp is the best";
let label = LabeledSpan::at(0..3, "should be Rust");
assert_eq!(
    label,
    LabeledSpan::new(Some("should be Rust".to_string()), 0, 3)
)
pub fn at_offset(offset: usize, label: impl Into<String>) -> LabeledSpan

Makes a new label that points at a specific offset.

Examples
use miette::LabeledSpan;

let source = "(2 + 2";
let label = LabeledSpan::at_offset(4, "expected a closing parenthesis");
assert_eq!(
    label,
    LabeledSpan::new(Some("expected a closing parenthesis".to_string()), 4, 0)
)
pub fn underline(span: impl Into<SourceSpan>) -> LabeledSpan

Makes a new label without text, that underlines a specific span.

Examples
use miette::LabeledSpan;

let source = "You have an eror here";
let label = LabeledSpan::underline(12..16);
assert_eq!(label, LabeledSpan::new(None, 12, 4))
pub fn label(&self) -> Option<&str>

Gets the (optional) label string for this LabeledSpan.

pub const fn inner(&self) -> &SourceSpan

Returns a reference to the inner SourceSpan.

pub const fn offset(&self) -> usize

Returns the 0-based starting byte offset.

pub const fn len(&self) -> usize

Returns the number of bytes this LabeledSpan spans.

pub const fn is_empty(&self) -> bool

True if this LabeledSpan is empty.

pub const fn primary(&self) -> bool

True if this LabeledSpan is a primary span.